@@ -8,7 +8,7 @@ from robotpy_toolkit_7407.utils.units import rev, minute, radians, radians_per_s
 
 from robotpy_toolkit_7407.unum import Unum
 
-from ctre_motors import hundred_ms
+from robotpy_toolkit_7407.motors.ctre_motors import hundred_ms
 
 
 @dataclass
